@@ -16,8 +16,7 @@ def main(args=None, plugins=None):
                   initialization.
     """
     config = _prepareconfig(args, plugins)
-    exitstatus = config.hook.pytest_cmdline_main(config=config)
-    return exitstatus
+    return config.hook.pytest_cmdline_main(config=config)
 
 class cmdline:  # compatibility namespace
     main = staticmethod(main)
@@ -41,7 +40,7 @@ def get_plugin_manager():
         return _preinit.pop(0)
     # subsequent calls to main will create a fresh instance
     pluginmanager = PytestPluginManager()
-    pluginmanager.config = config = Config(pluginmanager) # XXX attr needed?
+    pluginmanager.config = Config(pluginmanager) # XXX attr needed?
     for spec in default_plugins:
         pluginmanager.import_plugin(spec)
     return pluginmanager
