@@ -1,6 +1,8 @@
-import pytest
+# -*- coding: utf-8 -*-
+
 from xml.dom import minidom
 import py, sys, os
+from _pytest.junitxml import LogXML
 
 def runandparse(testdir, *args):
     resultpath = testdir.tmpdir.join("junit.xml")
@@ -370,7 +372,7 @@ def test_nullbyte(testdir):
             assert False
     """)
     xmlf = testdir.tmpdir.join('junit.xml')
-    result = testdir.runpytest('--junitxml=%s' % xmlf)
+    testdir.runpytest('--junitxml=%s' % xmlf)
     text = xmlf.read()
     assert '\x00' not in text
     assert '#x00' in text
@@ -386,7 +388,7 @@ def test_nullbyte_replace(testdir):
             assert False
     """)
     xmlf = testdir.tmpdir.join('junit.xml')
-    result = testdir.runpytest('--junitxml=%s' % xmlf)
+    testdir.runpytest('--junitxml=%s' % xmlf)
     text = xmlf.read()
     assert '#x0' in text
 
@@ -405,7 +407,6 @@ def test_invalid_xml_escape():
         unichr(65)
     except NameError:
         unichr = chr
-    u = py.builtin._totext
     invalid = (0x00, 0x1, 0xB, 0xC, 0xE, 0x19,
                 27, # issue #126
                0xD800, 0xDFFF, 0xFFFE, 0x0FFFF) #, 0x110000)
@@ -425,8 +426,6 @@ def test_invalid_xml_escape():
         assert chr(i) == bin_xml_escape(unichr(i)).uniobj
 
 def test_logxml_path_expansion(tmpdir, monkeypatch):
-    from _pytest.junitxml import LogXML
-
     home_tilde = py.path.local(os.path.expanduser('~')).join('test.xml')
 
     xml_tilde = LogXML('~%stest.xml' % tmpdir.sep, None)
@@ -463,3 +462,26 @@ def test_escaped_parametrized_names_xml(testdir):
     assert_attr(node,
         name="test_func[#x00]")
 
+def test_unicode_issue368(testdir):
+    path = testdir.tmpdir.join("test.xml")
+    log = LogXML(str(path), None)
+    ustr = py.builtin._totext("ВНИ!", "utf-8")
+    class report:
+        longrepr = ustr
+        sections = []
+        nodeid = "something"
+
+    # hopefully this is not too brittle ...
+    log.pytest_sessionstart()
+    log._opentestcase(report)
+    log.append_failure(report)
+    log.append_collect_failure(report)
+    log.append_collect_skipped(report)
+    log.append_error(report)
+    report.longrepr = "filename", 1, ustr
+    log.append_skipped(report)
+    report.wasxfail = ustr
+    log.append_skipped(report)
+    log.pytest_sessionfinish()
+
+
