@@ -1,8 +1,7 @@
 import pytest
 import sys
 
-from _pytest.skipping import MarkEvaluator, folded_skips
-from _pytest.skipping import pytest_runtest_setup
+from _pytest.skipping import MarkEvaluator, folded_skips, pytest_runtest_setup
 from _pytest.runner import runtestprotocol
 
 class TestEvaluator:
@@ -108,7 +107,7 @@ class TestEvaluator:
                 pass
         """)
         ev = MarkEvaluator(item, 'skipif')
-        exc = pytest.raises(pytest.fail.Exception, "ev.istrue()")
+        exc = pytest.raises(pytest.fail.Exception, ev.istrue)
         assert """Failed: you need to specify reason=STRING when using booleans as conditions.""" in exc.value.msg
 
     def test_skipif_class(self, testdir):
@@ -159,13 +158,14 @@ class TestXFail:
             @pytest.mark.xfail
             def test_func():
                 assert 0
+            def test_func2():
+                pytest.xfail("hello")
         """)
         result = testdir.runpytest("--runxfail")
-        assert result.ret == 1
         result.stdout.fnmatch_lines([
             "*def test_func():*",
             "*assert 0*",
-            "*1 failed*",
+            "*1 failed*1 pass*",
         ])
 
     def test_xfail_evalfalse_but_fails(self, testdir):
@@ -188,7 +188,7 @@ class TestXFail:
             def test_this():
                 assert 0
         """)
-        result = testdir.runpytest(p, '-v')
+        testdir.runpytest(p, '-v')
         #result.stdout.fnmatch_lines([
         #    "*HINT*use*-r*"
         #])
@@ -261,10 +261,7 @@ class TestXFail:
             "*reason:*hello*",
         ])
         result = testdir.runpytest(p, "--runxfail")
-        result.stdout.fnmatch_lines([
-            "*def test_this():*",
-            "*pytest.xfail*",
-        ])
+        result.stdout.fnmatch_lines("*1 pass*")
 
     def test_xfail_imperative_in_setup_function(self, testdir):
         p = testdir.makepyfile("""
@@ -285,10 +282,10 @@ class TestXFail:
             "*reason:*hello*",
         ])
         result = testdir.runpytest(p, "--runxfail")
-        result.stdout.fnmatch_lines([
-            "*def setup_function(function):*",
-            "*pytest.xfail*",
-        ])
+        result.stdout.fnmatch_lines("""
+            *def test_this*
+            *1 fail*
+        """)
 
     def xtest_dynamic_xfail_set_during_setup(self, testdir):
         p = testdir.makepyfile("""
@@ -372,8 +369,9 @@ class TestSkipif:
             @pytest.mark.skipif("hasattr(os, 'sep')")
             def test_func():
                 pass
-        """)
-        x = pytest.raises(pytest.skip.Exception, "pytest_runtest_setup(item)")
+        """) # noqa
+        x = pytest.raises(pytest.skip.Exception, lambda:
+                          pytest_runtest_setup(item))
         assert x.value.msg == "condition: hasattr(os, 'sep')"
 
 
